@@ -27,7 +27,7 @@ def view(dsdl_yaml, config, location, num, random, visualize, fields, task):
     config_dic = {}
     with open(config, encoding='utf-8') as config_file:
         exec(config_file.read(), config_dic)
-    location_config = config_dic["local_config" if location == "local" else "ali_oss_config"]
+    location_config = config_dic["local" if location == "local" else "ali_oss"]
 
     dataset = Dataset(dsdl_yaml, location_config)
     palette = {}
